BitwuzlaParser
==============

- typedef struct :cpp:type:`BitwuzlaParser`
- :cpp:func:`bitwuzla_parser_new()`
- :cpp:func:`bitwuzla_parser_delete()`
- :cpp:func:`bitwuzla_parser_parse()`
- :cpp:func:`bitwuzla_parser_get_bitwuzla()`

----


.. doxygentypedef:: BitwuzlaParser
    :project: Bitwuzla_c

----

.. doxygengroup:: c_bitwuzlaparser
    :project: Bitwuzla_c
    :content-only:
